Worker and its components
=========================

.. automodule:: orion.core.worker
   :members:

.. toctree::
   :maxdepth: 1
   :caption: Modules

   worker/experiment
   worker/trial
   worker/producer
   worker/consumer
   worker/primary_algo
   worker/transformer
